@@ -34,7 +34,7 @@ from fnmatch import fnmatch
 from functools import total_ordering
 from logging import getLogger
 from time import sleep
-from typing import Mapping, MutableMapping
+from typing import Mapping, MutableMapping, Optional
 from urllib.parse import quote
 from xml.parsers.expat import ExpatError
 
@@ -493,6 +493,36 @@ class Item(BaseItem):
         r.raise_for_status()
         return r
 
+    def index_review(self, username=None, screenname=None, itemname=None) -> Response:
+        u = f'{self.session.protocol}//{self.session.host}/services/reviews.php'
+        p = {'identifier': self.identifier}
+        d = {'noindex': '0'}
+        if username:
+            d['username'] = username
+        elif screenname:
+            d['screenname'] = screenname
+        elif itemname:
+            d['itemname'] = itemname
+        a = S3Auth(self.session.access_key, self.session.secret_key)
+        r = self.session.put(u, params=p, data=d, auth=a)
+        r.raise_for_status()
+        return r
+
+    def noindex_review(self, username=None, screenname=None, itemname=None) -> Response:
+        u = f'{self.session.protocol}//{self.session.host}/services/reviews.php'
+        p = {'identifier': self.identifier}
+        d = {'noindex': '1'}
+        if username:
+            d['username'] = username
+        elif screenname:
+            d['screenname'] = screenname
+        elif itemname:
+            d['itemname'] = itemname
+        a = S3Auth(self.session.access_key, self.session.secret_key)
+        r = self.session.put(u, params=p, data=d, auth=a)
+        r.raise_for_status()
+        return r
+
     def delete_review(self, username=None, screenname=None, itemname=None) -> Response:
         u = f'{self.session.protocol}//{self.session.host}/services/reviews.php'
         p = {'identifier': self.identifier}
@@ -532,8 +562,8 @@ class Item(BaseItem):
     def get_files(self,
                   files: File | list[File] | None = None,
                   formats: str | list[str] | None = None,
-                  glob_pattern: str | None = None,
-                  exclude_pattern: str | None = None,
+                  glob_pattern: str | list[str] | None = None,
+                  exclude_pattern: str | list[str] | None = None,
                   on_the_fly: bool = False):
         files = files or []
         formats = formats or []
@@ -871,6 +901,39 @@ class Item(BaseItem):
             self.refresh()
         return resp
 
+    def delete_flag(
+            self,
+            category: str,
+            user: Optional[str] = None,  # noqa: UP007
+    ) -> Response:
+        if user is None:
+            user = f"@{self.session.config.get('general', {}).get('screenname')}"
+        url = f'{self.session.protocol}//{self.session.host}/services/flags/admin.php'
+        headers = {'Accept': 'text/json'}  # must be text/json specifically
+        params = {'identifier': self.identifier, 'category': category, 'user': user}
+        r = self.session.delete(url, headers=headers, params=params)
+        return r
+
+    def add_flag(
+            self,
+            category: str,
+            user: Optional[str] = None,  # noqa: UP007
+    ) -> Response:
+        if user is None:
+            user = f"@{self.session.config.get('general', {}).get('screenname')}"
+        url = f'{self.session.protocol}//{self.session.host}/services/flags/admin.php'
+        headers = {'Accept': 'text/json'}  # must be text/json specifically
+        params = {'identifier': self.identifier, 'category': category, 'user': user}
+        r = self.session.put(url, headers=headers, params=params)
+        return r
+
+    def get_flags(self) -> Response:
+        url = f'{self.session.protocol}//{self.session.host}/services/flags/admin.php'
+        headers = {'Accept': 'text/json'}  # must be text/json specifically
+        params = {'identifier': self.identifier}
+        r = self.session.get(url, headers=headers, params=params)
+        return r
+
     # TODO: `list` parameter name shadows the Python builtin
     def remove_from_simplelist(self, parent, list) -> Response:
         """Remove item from a simplelist.
