@@ -8,12 +8,6 @@ def test_ia(capsys):
 
     ia_call(['ia', '--insecure', 'ls', 'nasa'])
 
-    ia_call(['ia', 'nocmd'], expected_exit_code=127)
+    ia_call(['ia', 'nocmd'], expected_exit_code=2)
     out, err = capsys.readouterr()
-    assert "error: 'nocmd' is not an ia command!" in err
-
-    ia_call(['ia', 'help'])
-    out, err = capsys.readouterr()
-    assert 'A command line interface to Archive.org.' in err
-
-    ia_call(['ia', 'help', 'list'])
+    assert "invalid choice: 'nocmd'" in err
